@@ -12,6 +12,12 @@
 #undef HAVE_SHADOW_H
 #undef HAVE_LINUX_TABLE
 
+/* Define if your struct tm has tm_gmtoff.  */
+#undef HAVE_TM_GMTOFF
+
+/* Define if you don't have tm_gmtoff but do have the external timezone.  */
+#undef HAVE_TIMEZONE
+
 /* Define if you want to build against development gtk */
 #undef HAVE_DEVGTK
 
