@@ -263,22 +263,31 @@ static void save_calendar_cmd (GtkWidget *widget, void *data);
 static void
 about_calendar_cmd (GtkWidget *widget, void *data)
 {
-        GtkWidget *about;
-        const gchar *authors[] = {
-		"Miguel de Icaza (miguel@kernel.org)",
-		"Federico Mena (federico@gimp.org)",
-		"Arturo Espinosa (arturo@nuclecu.unam.mx)",
-		"Russell Steinthal (rms39@columbia.edu)",
-		NULL
-	};
+        static GtkWidget *about;
+        const gchar *authors[5];
+
+	if (about != NULL)
+	{
+		gdk_window_show (about->window);
+		gdk_window_raise (about->window);
+		return TRUE;
+	}
+
+	authors[0] = "Miguel de Icaza (miguel@kernel.org)";
+	authors[1] = "Federico Mena (federico@gimp.org)";
+	authors[2] = "Arturo Espinosa (arturo@nuclecu.unam.mx)";
+	authors[3] = "Russell Steinthal (rms39@columbia.edu)";
+	authors[4] = NULL;
 
         about = gnome_about_new (_("Gnome Calendar"), VERSION,
 				 "(C) 1998 the Free Software Foundation",
 				 authors,
 				 _("The GNOME personal calendar and schedule manager."),
 				 NULL);
-	gtk_window_set_modal (GTK_WINDOW (about), TRUE);
-	gnome_dialog_set_close (GNOME_DIALOG (about), TRUE);
+
+	gtk_signal_connect (GTK_OBJECT (about), "destroy",
+			    GTK_SIGNAL_FUNC (gtk_widget_destroyed), &about);
+
         gtk_widget_show (about);
 }
 
@@ -493,7 +502,7 @@ save_ok (GtkWidget *widget, GtkFileSelection *fs)
 	fname = g_strdup (gtk_file_selection_get_filename (fs));
 	calendar_save (gcal->cal, fname);
 	g_free(fname);
-	gtk_widget_destroy (fs);
+	gtk_widget_destroy (GTK_WIDGET (fs));
 }
 
 static gint
@@ -702,7 +711,7 @@ new_calendar (char *full_name, char *calendar_file, char *geometry, char *page,
 	g_snprintf(title, 128, _("%s%s"), full_name, _("'s calendar"));
 
 	toplevel = gnome_calendar_new (title);
-	    
+	
 	if (gnome_parse_geometry (geometry, &xpos, &ypos, &width, &height)){
 		if (xpos != -1)
 			gtk_widget_set_uposition (toplevel, xpos, ypos);
@@ -717,7 +726,9 @@ new_calendar (char *full_name, char *calendar_file, char *geometry, char *page,
 
 	setup_appbar (toplevel);
 	setup_menu (toplevel);
-
+	
+	gtk_widget_realize (toplevel);
+	/*set_icon (toplevel);*/
 
 	if (page)
 		gnome_calendar_set_view (GNOME_CALENDAR (toplevel), page);
