@@ -91,20 +91,13 @@ getSortFuncFromColType(gint sort_col)
 	func = gnomecard_cmp_emails;
 	break;
 
-      case COLTYPE_WEBPAGE:
+      case COLTYPE_URL:
 	func = gnomecard_cmp_urls;
 	break;
 
-      case COLTYPE_HOMEPHONE:
+      case COLTYPE_PHONE:
 	func = NULL;
 	break;
-
-      case COLTYPE_WORKPHONE:
-	func = NULL;
-	break;
-	
-      default:
-	break;
     }
 
     return func;
